@@ -8,15 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 5469 2012-12-13 14:11:00Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 5580 2013-01-27 12:21:02Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
 {
-	private static $jQueryVer = 0;			// 使用するjQueryのバージョン(0=2.6、1=最新)
-	
+	private static $jQueryVer = 1.8;			// 使用するjQueryのバージョン
+	private static $jQueryVersionArray = array(	'1.6' => 'jquery-1.6.4.min.js',// jQueryバージョン
+												'1.7' => 'jquery-1.7.2.min.js',
+												'1.8' => 'jquery-1.8.3.min.js');
 	// Javascriptライブラリ(DBでの設定値)
 	// ベースライブラリ
 	const LIB_JQUERY				= 'jquery';
@@ -62,6 +64,7 @@ class ScriptLibInfo
 	
 	// jQueryプラグインバージョン
 	const JQUERY_JCAROUSEL_VER		= '0.2.8';
+	const JQUERY_THICKBOX_VER		= '3.1';
 //	const JQUERY_PRETTYPHOTO_VER	= '2.5.6';
 	const JQUERY_PRETTYPHOTO_VER	= '3.1.4';
 	const JQUERY_QTIP_VER			= '1.0';
@@ -95,7 +98,7 @@ class ScriptLibInfo
 	//const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.4.min.js';		// jQuery1.4.2対応版
 	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.8.min.js';		// jQuery1.4.2対応版
 	const JQUERY_CONTEXTMENU_FILENAME	= 'jquery/jquery.contextmenu.r2.packed.js';
-	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox-compressed.js';
+	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox3.1.js';
 	const JQUERY_THICKBOX_CSS			= 'jquery/thickbox.css';
 //	const JQUERY_JSHOTKEYS_FILENAME		= 'jquery/jquery.hotkeys.js';
 	const JQUERY_CYCLE_FILENAME			= 'jquery/jquery.cycle.all.pack.js';
@@ -141,6 +144,7 @@ class ScriptLibInfo
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_JCAROUSEL_URL			= 'http://sorgalla.com/projects/jcarousel/';
+	const JQUERY_THICKBOX_URL			= 'http://thickbox.net/';
 	const JQUERY_CLUETIP_URL			= 'http://plugins.learningjquery.com/cluetip/';
 	const JQUERY_FACEBOX_URL			= 'http://defunkt.github.com/facebox/';
 	const JQUERY_CURVYCORNERS_URL		= 'http://code.google.com/p/jquerycurvycorners/';
@@ -216,32 +220,33 @@ class ScriptLibInfo
 	{
 		$filename = '';
 		if ($type == 0){	// jQuery
-			switch (self::$jQueryVer){
+			$filename = self::$jQueryVersionArray[self::$jQueryVer];
+			if (empty($filename)) $filename = self::JQUERY_L_FILENAME;	// jQuery本体
+/*			switch (self::$jQueryVer){
 				case 0:		// デフォルトのとき
 					$filename = self::JQUERY_FILENAME;	// jquery
 					break;
-				case 1:		// 最新のとき
-					$filename = self::JQUERY_L_FILENAME;	// jquery
-					break;
-			}
+				case 1:		// 最新のとき*/
+//					break;
+//			}
 		} else if ($type == 1){	// Core
-			switch (self::$jQueryVer){
+/*			switch (self::$jQueryVer){
 				case 0:		// デフォルトのとき
 					$filename = self::JQUERY_UI_CORE_FILENAME;	// jquery
 					break;
-				case 1:		// 最新のとき
+				case 1:		// 最新のとき*/
 					$filename = self::JQUERY_L_UI_CORE_FILENAME;	// jquery UI
-					break;
-			}
+//					break;
+//			}
 		} else if ($type == 2){	// Plus
-			switch (self::$jQueryVer){
+/*			switch (self::$jQueryVer){
 				case 0:		// デフォルトのとき
 					$filename = self::JQUERY_UI_PLUS_FILENAME;	// jquery
 					break;
-				case 1:		// 最新のとき
+				case 1:		// 最新のとき*/
 					$filename = self::JQUERY_L_UI_PLUS_FILENAME;	// jquery UI
-					break;
-			}
+//					break;
+//			}
 		} else if ($type == 10){	// スマートフォン用jQuery
 			$filename = self::JQUERYS_FILENAME;
 		}
@@ -264,7 +269,9 @@ class ScriptLibInfo
 																'url'		=>	self::JQUERY_JCAROUSEL_URL,
 																'version'	=>	self::JQUERY_JCAROUSEL_VER),			// jquery.jcarousel用のファイル
 					self::LIB_JQUERY_THICKBOX		=>	array(	'script' 	=> array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
-																'css'		=> array(self::JQUERY_THICKBOX_CSS)),
+																'css'		=> array(self::JQUERY_THICKBOX_CSS),
+																'url'		=>	self::JQUERY_THICKBOX_URL,
+																'version'	=>	self::JQUERY_THICKBOX_VER),
 //					self::LIB_JQUERY_JSHOTKEYS		=>	array(	'script' 	=> array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
 					self::LIB_JQUERY_CYCLE			=>	array(	'script' 	=> array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
 					self::LIB_JQUERY_CODEPRESS		=>	array(	'script' 	=> array(self::JQUERY_CODEPRESS_FILENAME)),	// jquery.codepress用のファイル
@@ -324,13 +331,13 @@ class ScriptLibInfo
 																);
 					
 		// 使用するjQueryバージョンに合わせてファイルを追加
-		switch (self::$jQueryVer){
+/*		switch (self::$jQueryVer){
 			case 0:		// デフォルトのとき
 				$libs[self::LIB_JQUERY] = array(	'script' => array(self::getJQueryFilename(0)));	// jquery
 				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_UI_CORE_FILENAME));	// jquery ui
 				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
 				break;
-			case 1:		// 最新のとき
+			case 1:		// 最新のとき*/
 				$libs[self::LIB_JQUERY] = array(	'script' => array(self::getJQueryFilename(0)));	// jquery
 				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_L_UI_CORE_FILENAME));	// jquery ui
 				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_L_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
@@ -345,8 +352,8 @@ class ScriptLibInfo
 				$libs[self::LIB_JQUERY_UI_WIDGETS_SLIDER]		= array(	'script' => array(self::JQUERY_UI_WIDGETS_SLIDER_FILENAME));		// Widgets Slider
 				$libs[self::LIB_JQUERY_UI_WIDGETS_TABS]			= array(	'script' => array(self::JQUERY_UI_WIDGETS_TABS_FILENAME));			// Widgets Tabs
 				$libs[self::LIB_JQUERY_UI_EFFECTS]				= array(	'script' => array(self::JQUERY_UI_EFFECTS_FILENAME));				// Effects
-				break;
-		}
+//				break;
+//		}
 		
 		// スマートフォン用jQueryライブラリ
 		$libs[self::LIB_JQUERYS] 			= array(	'script' => array(self::getJQueryFilename(10)));		// スマートフォン用jQuery
@@ -365,9 +372,9 @@ class ScriptLibInfo
 		static $jQueryUiInfo;		// jQuery UIの情報
 		
 		if (!isset($jQueryUiInfo)){
-			if (self::$jQueryVer == 0){		// デフォルトのとき
+/*			if (self::$jQueryVer == 0){		// デフォルトのとき
 				$jQueryUiInfo = array();
-			} else {
+			} else {*/
 			/*
 				$jQueryUiInfo = array(
 					self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> array(self::LIB_JQUERY_UI),		// Widgets Accordion
@@ -395,7 +402,7 @@ class ScriptLibInfo
 					self::LIB_JQUERY_UI_WIDGETS_TABS			=> $defaultLib,		// Widgets Tabs
 					self::LIB_JQUERY_UI_EFFECTS					=> $defaultLib		// Effects
 				);
-			}
+//			}
 		}
 		return $jQueryUiInfo;
 	}
