@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: imageManager.php 5227 2012-09-19 04:28:14Z fishbone $
+ * @version    SVN: $Id: imageManager.php 5367 2012-11-08 13:32:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -104,9 +104,11 @@ class ImageManager extends Core
 
 				// サムネールの作成
 				if ($thumbAttr == 'c'){		// 切り取りサムネールの場合
-					$ret = $this->gInstance->getImageManager()->createThumb($path, $thumbPath, $thumbSize, $imageType, true);
+					//$ret = $this->gInstance->getImageManager()->createThumb($path, $thumbPath, $thumbSize, $imageType, true);
+					$ret = $this->createThumb($path, $thumbPath, $thumbSize, $imageType, true);
 				} else {
-					$ret = $this->gInstance->getImageManager()->createThumb($path, $thumbPath, $thumbSize, $imageType, false);
+					//$ret = $this->gInstance->getImageManager()->createThumb($path, $thumbPath, $thumbSize, $imageType, false);
+					$ret = $this->createThumb($path, $thumbPath, $thumbSize, $imageType, false);
 				}
 				if ($ret){
 					$destFilename[] = $thumbFilename;
@@ -256,7 +258,7 @@ class ImageManager extends Core
 	 *
 	 * @param string $path		元の画像ファイル
 	 * @param string $destPath	サムネールファイルパス
-	 * @param int $size			サムネールの縦横サイズ
+	 * @param int,array $size	サムネールの縦横サイズ(縦横異なる場合は連想配列(width,height))
 	 * @param int $type			サムネールの画像タイプ
 	 * @param bool $useCrop		画像切り取りありかどうか
 	 * @param string $bgColor	背景色。設定しない場合は空文字列
@@ -294,19 +296,40 @@ class ImageManager extends Core
 		$newY = 0;
 		$width = imagesx($imageObj);
 		$height = imagesy($imageObj);
+		if (is_array($size)){
+			$destWidth = $size['width'];		// サムネールの幅
+			$destHeight = $size['height'];		// サムネールの高さ
+		} else {
+			$destWidth = $size;		// サムネールの幅
+			$destHeight = $size;		// サムネールの高さ
+		}
 		if ($useCrop){		// 画像切り取りありのとき
-			if ($width > $height){
-				$newHeight	= $size;
-				$newWidth	= round($size * $width / $height);
-
-				$x = ceil(($width - $height) / 2);
-				$y = 0;
+			if (is_array($size)){
+				if ($height / $destHeight < $width / $destWidth){
+					$newHeight	= $destHeight;
+					$newWidth	= round($destHeight * $width / $height);
+					$x = ceil(($newWidth - $destWidth) / 2);
+					$y = 0;
+				} else {
+					$newWidth	= $destWidth;
+					$newHeight	= round($destWidth * $height / $width);
+					$x = 0;
+					$y = ceil(($newHeight - $destHeight) / 2);
+				}
 			} else {
-				$newWidth	= $size;
-				$newHeight	= round($size * $height / $width);
+				if ($width > $height){
+					$newHeight	= $size;
+					$newWidth	= round($size * $width / $height);
 
-				$x = 0;
-				$y = ceil(($height - $width) / 2);
+					$x = ceil(($width - $height) / 2);
+					$y = 0;
+				} else {
+					$newWidth	= $size;
+					$newHeight	= round($size * $height / $width);
+
+					$x = 0;
+					$y = ceil(($height - $width) / 2);
+				}
 			}
 		} else {
 			if ($width > $height){
@@ -324,7 +347,8 @@ class ImageManager extends Core
 		}
 
 		// TrueColorイメージを作成
-		$thumbObj = imagecreatetruecolor($size, $size);
+		//$thumbObj = imagecreatetruecolor($size, $size);
+		$thumbObj = imagecreatetruecolor($destWidth, $destHeight);
 		
 		// 背景色の設定		
 		if (!$useCrop){			// 切り取りなしのとき
@@ -477,9 +501,11 @@ class ImageManager extends Core
 
 				// サムネールの作成
 				if ($imageAttr == 'c'){		// 切り取りサムネールの場合
-					$ret = $this->gInstance->getImageManager()->createThumb($path, $newPath, $imageSize, $imageType, true);
+					//$ret = $this->gInstance->getImageManager()->createThumb($path, $newPath, $imageSize, $imageType, true);
+					$ret = $this->createThumb($path, $newPath, $imageSize, $imageType, true);
 				} else {
-					$ret = $this->gInstance->getImageManager()->createThumb($path, $newPath, $imageSize, $imageType, false);
+					//$ret = $this->gInstance->getImageManager()->createThumb($path, $newPath, $imageSize, $imageType, false);
+					$ret = $this->createThumb($path, $newPath, $imageSize, $imageType, false);
 				}
 				if ($ret){
 					$destFilename[] = $newFilename;
@@ -498,18 +524,25 @@ class ImageManager extends Core
 	 * @param string $format		画像フォーマット
 	 * @param string $imageType		画像タイプ
 	 * @param string $imageAttr		画像属性(c=切り取りあり)
-	 * @param string $imageSize		画像サイズ
+	 * @param string,array $imageSize		画像サイズ(縦横異なる場合は連想配列(width,height))
 	 * @return bool					true=取得成功、false=取得失敗
 	 */
 	function parseImageFormat($format, &$imageType, &$imageAttr, &$imageSize)
 	{
 		$format = trim($format);
-		$ret = preg_match('/(\d+)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);
+		//$ret = preg_match('/(\d+)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);
+		$ret = preg_match('/(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);	// 「MMxNNc.jpg」タイプのフォーマットを解析
 		if ($ret){
 			$imageSize = $matches[1];
-			$imageAttr = strtolower($matches[2]);
-			$ext = strtolower($matches[3]);
-
+			$height = intval($matches[3]);
+			if ($height > 0){
+				$imageSize = array('width' => $imageSize, 'height' => $height);
+			}
+			//$imageAttr = strtolower($matches[2]);
+			//$ext = strtolower($matches[3]);
+			$imageAttr = strtolower($matches[4]);
+			$ext = strtolower($matches[5]);
+			
 			$imageType = IMAGETYPE_JPEG;
 			switch ($ext){
 				case 'jpg':
